[Scummvm-cvs-logs] CVS: scummvm/queen command.cpp,1.55,1.56 credits.cpp,1.3,1.4 credits.h,1.2,1.3 cutaway.cpp,1.108,1.109 cutaway.h,1.32,1.33 display.cpp,1.50,1.51

Gregory Montoir cyx at users.sourceforge.net
Sat Jan 10 04:57:03 CET 2004


Update of /cvsroot/scummvm/scummvm/queen
In directory sc8-pr-cvs1:/tmp/cvs-serv6433/queen

Modified Files:
	command.cpp credits.cpp credits.h cutaway.cpp cutaway.h 
	display.cpp 
Log Message:
this should fix :
- minor sound glitch in room 50 (temple zombies)
- panel undisplayed at the end of cutaway c62c 
- wrong dirty blocks in room 76
- Cutaway::_cutAnim is now a 21x30 elements array. This is needed for cutaway c69g, where we setup
  frames for bob num 20 (the original game uses the same value)
- Credits::_list is now a 18 elements array (that's what credits2.crd need)


Index: command.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/command.cpp,v
retrieving revision 1.55
retrieving revision 1.56
diff -u -d -r1.55 -r1.56
--- command.cpp	9 Jan 2004 13:36:37 -0000	1.55
+++ command.cpp	10 Jan 2004 12:56:07 -0000	1.56
@@ -407,7 +407,9 @@
 	}
 
 	// don't play music on an OPEN/CLOSE command - in case the command fails
-	if (_state.selAction != VERB_OPEN && _state.selAction != VERB_CLOSE) {
+	if (_state.selAction != VERB_NONE && 
+		_state.selAction != VERB_OPEN && 
+		_state.selAction != VERB_CLOSE) {
 		// only play song if it's a PLAY BEFORE type
 		if (com->song > 0) {
 			_vm->sound()->playSong(com->song);

Index: credits.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/credits.cpp,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- credits.cpp	9 Jan 2004 13:36:37 -0000	1.3
+++ credits.cpp	10 Jan 2004 12:56:07 -0000	1.4
@@ -128,10 +128,10 @@
 
 		}
 		else {
+			assert(_count < ARRAYSIZE(_list));
 			_list[_count].text = line;
 			_list[_count].color = _color;
 			_list[_count].fontSize = _fontSize;
-
 			switch (_justify) {
 				case 0:
 					_list[_count].x = (_zone % 3) * (320 / 3) + 8;

Index: credits.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/credits.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- credits.h	6 Jan 2004 12:45:29 -0000	1.2
+++ credits.h	10 Jan 2004 12:56:07 -0000	1.3
@@ -53,7 +53,7 @@
 		char *text;
 	};
 
-	Line _list[15];
+	Line _list[18];
 
 	bool _running;
 	int _count;

Index: cutaway.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/cutaway.h,v
retrieving revision 1.32
retrieving revision 1.33
diff -u -d -r1.32 -r1.33
--- cutaway.h	8 Jan 2004 10:25:17 -0000	1.32
+++ cutaway.h	10 Jan 2004 12:56:07 -0000	1.33
@@ -194,7 +194,7 @@
 
 		int16 _currentImage;
 
-		AnimFrame _cutAnim[17][30];
+		AnimFrame _cutAnim[21][30];
 
 		Cutaway(const char *filename, 
 				QueenEngine *vm);

Index: display.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/display.cpp,v
retrieving revision 1.50
retrieving revision 1.51
diff -u -d -r1.50 -r1.51
--- display.cpp	9 Jan 2004 15:14:15 -0000	1.50
+++ display.cpp	10 Jan 2004 12:56:07 -0000	1.51
@@ -570,9 +570,9 @@
 	}
 
 	if (comPanel == 2 && inCutaway) {
-		_fullscreen = (_bdHeight == GAME_SCREEN_HEIGHT);
+		fullscreen((_bdHeight == GAME_SCREEN_HEIGHT));
 	} else if (comPanel == 1) {
-		_fullscreen = false;
+		fullscreen(false);
 	}
 }
 





More information about the Scummvm-git-logs mailing list
Index: cutaway.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/queen/cutaway.cpp,v
retrieving revision 1.108
retrieving revision 1.109
diff -u -d -r1.108 -r1.109
--- cutaway.cpp	9 Jan 2004 13:36:37 -0000	1.108
+++ cutaway.cpp	10 Jan 2004 12:56:07 -0000	1.109
@@ -390,12 +390,14 @@
 
 	_vm->logic()->oldRoom(_initialRoom);
 
 	// FIXME: this cutaway is played at the end of the command 0x178. This command
 	// setups some persons and associates bob slots to them. They should be hidden
 	// as their y coordinate is > 150, but they aren't ! A (temporary) workaround
 	// is to display the room with the panel area enabled.
 	int16 comPanel = _comPanel;
-	if (strcmp(_basename, "c41f") == 0 && _temporaryRoom == 106 && object.room == 41) {
+	if ((strcmp(_basename, "c41f") == 0 && _temporaryRoom == 106 && object.room == 41) ||
+		(strcmp(_basename, "c62c") == 0 && _temporaryRoom == 105 && object.room == 41)) {
 		comPanel = 1;
 	}
 
@@ -820,7 +822,7 @@
 
 	if (0 != strcmp(sentence, "*")) {
 		if (sentence[0] == '#') {
-			debug(0, "Starting credits");
+			debug(0, "Starting credits '%s'", sentence + 1);
 			_vm->logic()->startCredits(sentence + 1);
 		}
 		else {
@@ -1286,7 +1288,8 @@
 	int frameIndex[256];
 	int i;
 	int bobNum = objAnim[0].object;
-
+	assert(bobNum < 21);
+	
 	memset(frameIndex, 0, sizeof(frameIndex));
 	debug(6, "[Cutaway::makeComplexAnimation] currentImage = %i", currentImage);
 
@@ -390,12 +390,14 @@
 	_vm->logic()->oldRoom(_initialRoom);
 
-	// FIXME: this cutaway is played at the end of the command 0x178. This command
-	// setups some persons and associates bob slots to them. They should be hidden
-	// as their y coordinate is > 150, but they aren't ! A (temporary) workaround
-	// is to display the room with the panel area enabled.
+	// FIXME - the first cutaway is played at the end of the command 0x178. This 
+	// command setups some persons and associates bob slots to them. They should be 
+	// hidden as their y coordinate is > 150, but they aren't ! A (temporary) 
+	// workaround is to display the room with the panel area enabled. Same problem
+	// for cutaway c62c.
 	int16 comPanel = _comPanel;
